from django.db import models
from django.contrib.auth import get_user_model
from django.contrib.postgres.fields import JSONField
from django.conf import settings


UserModel = get_user_model()
# Create your models here.

class UserSettings(models.Model):
    key = models.CharField(max_length=250)
    value = JSONField()
    user = models.ForeignKey(UserModel,
                             db_column="user_id",
                             editable=True,
                             on_delete=models.SET_NULL,
                             blank=True,
                             default=None,
                             null=True
                             )
    created_at = models.DateTimeField(auto_now_add=True)
    updated_at = models.DateTimeField(auto_now=True)
    created_by = models.ForeignKey(
        settings.AUTH_USER_MODEL, related_name='%(class)s_createdby',
        editable=False, null=True, blank=True,
        on_delete=models.SET_NULL
    )
    modified_by = models.ForeignKey(
        settings.AUTH_USER_MODEL, related_name='%(class)s_modifiedby',
        null=True, blank=True, editable=False,
        on_delete=models.SET_NULL
    )
    is_archive = models.BooleanField(default=False, editable=False)

    def archive(self, user=None):
        update_fields = ['is_archive']

        if user:
            self.modified_by = user
            update_fields.append('modified_by')

        self.is_archive = True
        self.save(update_fields=update_fields)

    def __str__(self):
        return "Key: {}, Value: {}".format(self.key, self.value)

    def to_dict(self):
        return {
            "id": self.id,
            "key": self.key,
            "value": self.value,
            "user": self.user.id if self.user is not None else None,
            "created_by": self.created_by.id if self.created_by is not None else None,
            "modified_by": self.modified_by.id if self.modified_by is not None else None,
        }
    objects = models.Manager()



import setuptools

CLASSIFIERS = [
    'Environment :: Web Environment',
    'Framework :: Django',
    'Framework :: Django :: 2.0',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Topic :: Internet :: WWW/HTTP',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
]
with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="django-user-settings",
    version="0.0.3",
    author="viethq.lucidfoundry",
    author_email="viet.hoang@lucidfoundry.com",
    description="Enable settings for each user",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="",  # TODO add github url here
    packages=setuptools.find_packages(),
    classifiers=CLASSIFIERS
)



# Generated by Django 2.1.3 on 2018-11-20 06:48

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='UserSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('is_archive', models.BooleanField(default=False, editable=False)),
                ('key', models.CharField(max_length=250)),
                ('value', models.CharField(max_length=250)),
                ('active', models.BooleanField(default=True)),
                ('created_by', models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='usersettings_createdby', to=settings.AUTH_USER_MODEL)),
                ('modified_by', models.ForeignKey(blank=True, editable=False, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='usersettings_modifiedby', to=settings.AUTH_USER_MODEL)),
                ('user', models.ForeignKey(blank=True, db_column='user_id', default=None, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
